==> jcodemodel-2.7.3-sources.jar: com/helger/jcodemodel/JDoLoop.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.helger.jcodemodel;

import javax.annotation.Nonnull;

/**
 * Do loops
 */
public class JDoLoop implements IJStatement
{
  /**
   * Test part of Do statement for determining exit state
   */
  private final IJExpression _test;

  /**
   * JBlock of statements which makes up body of this Do statement
   */
  private JBlock _body;

  /**
   * Construct a Do statment
   */
  protected JDoLoop (@Nonnull final IJExpression test)
  {
    if (test == null)
      throw new NullPointerException ("test");
    this._test = test;
  }

  @Nonnull
  public IJExpression test ()
  {
    return _test;
  }

  @Nonnull
  public JBlock body ()
  {
    if (_body == null)
      _body = new JBlock ();
    return _body;
  }

  public void state (@Nonnull final JFormatter f)
  {
    f.print ("do");
    if (_body != null)
      f.generable (_body);
    else
      f.print ("{ }");

    if (JOp.hasTopOp (_test))
    {
      f.print ("while ").generable (_test);
    }
    else
    {
      f.print ("while (").generable (_test).print (')');
    }
    f.print (';').newline ();
  }
}

==> jcodemodel-2.8.6-sources.jar: com/helger/jcodemodel/JDoLoop.java <==
/**
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2010 Oracle and/or its affiliates. All rights reserved.
 * Portions Copyright 2013-2016 Philip Helger + contributors
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.helger.jcodemodel;

import javax.annotation.Nonnull;

import com.helger.jcodemodel.util.JCValueEnforcer;

/**
 * Do loops
 */
public class JDoLoop implements IJStatement
{
  /**
   * Test part of Do statement for determining exit state
   */
  private final IJExpression m_aTest;

  /**
   * JBlock of statements which makes up body of this Do statement
   */
  private JBlock m_aBody;

  /**
   * Construct a Do statement
   *
   * @param aTest
   *        Test expression
   */
  protected JDoLoop (@Nonnull final IJExpression aTest)
  {
    m_aTest = JCValueEnforcer.notNull (aTest, "Test");
  }

  @Nonnull
  public IJExpression test ()
  {
    return m_aTest;
  }

  @Nonnull
  public JBlock body ()
  {
    if (m_aBody == null)
      m_aBody = new JBlock ();
    return m_aBody;
  }

  public void state (@Nonnull final JFormatter f)
  {
    f.print ("do");
    if (m_aBody != null)
      f.generable (m_aBody);
    else
      f.print ("{ }");

    if (JOp.hasTopOp (m_aTest))
    {
      f.print ("while ").generable (m_aTest);
    }
    else
    {
      f.print ("while (").generable (m_aTest).print (')');
    }
    f.print (';').newline ();
  }
}
